Index: svn/src/Kconfig
===================================================================
--- svn.orig/src/Kconfig
+++ svn/src/Kconfig
@@ -74,10 +74,6 @@ config CPU_ADDR_BITS
 	int
 	default 36
 
-config AGP_APERTURE_SIZE
-	hex
-	default 0x0
-
 config XIP_ROM_BASE
 	hex
 	default 0xfffe0000
@@ -216,6 +212,7 @@ config IOAPIC
 	default n
 
 config VIDEO_MB
+	default 0
 	int
 
 config USE_WATCHDOG_ON_BOOT
@@ -230,6 +227,7 @@ config VGA
 
 config GFXUMA
 	bool
+	default n
 	help
 	  Enable Unified Memory Architecture for graphics.
 
@@ -238,6 +236,26 @@ config GFXUMA
 #
 # endmenu
 
+config HAVE_LOW_TABLES
+	bool
+	default y
+	help
+	  This Option is unused in the code.  Since two boards try to set it to
+	  'n', they may be broken.  We either need to make the option useful or
+	  get rid of it.  The broken boards are:
+	  asus/m2v-mx_se
+	  supermicro/h8dme
+
+config HAVE_HIGH_TABLES
+	bool
+	default n
+	help
+	  This variable specifies whether a given northbridge has high table
+	  support.
+	  It is set in northbridge/*/Kconfig.
+	  Whether or not the high tables are actually written by coreboot is
+	  configurable by the user via WRITE_HIGH_TABLES.
+
 config HAVE_ACPI_TABLES
 	bool
 	help
@@ -262,14 +280,30 @@ config HAVE_PIRQ_TABLE
 	  Whether or not the PIRQ table is actually generated by coreboot
 	  is configurable by the user via GENERATE_PIRQ_TABLE.
 
-config HAVE_HIGH_TABLES
+#These Options are here to avoid "undefined" warnings.
+#The actual selection and help texts are in the following menu.
+
+config GENERATE_ACPI_TABLES
 	bool
+	default y if HAVE_ACPI_TABLES
+	default n
 
-menu "System tables"
+config GENERATE_MP_TABLE
+	bool
+	default y if HAVE_MP_TABLE
+	default n
 
-config HAVE_LOW_TABLES
+config GENERATE_PIRQ_TABLE
 	bool
-	default y
+	default y if HAVE_PIRQ_TABLE
+	default n
+
+config WRITE_HIGH_TABLES
+	bool
+	default y if HAVE_HIGH_TABLES
+	default n
+
+menu "System tables"
 
 config WRITE_HIGH_TABLES
 	bool "Write 'high' tables to avoid being overwritten in F segment"
@@ -409,3 +443,16 @@ endmenu
 config LIFT_BSP_APIC_ID
 	bool
 	default n
+
+# These probably belong somewhere else, but they are needed somewhere.
+config AP_CODE_IN_CAR
+	bool
+	default n
+
+config USE_INIT
+	bool
+	default n
+
+config ENABLE_APIC_EXT_ID
+	bool
+	default n
Index: svn/src/console/Kconfig
===================================================================
--- svn.orig/src/console/Kconfig
+++ svn/src/console/Kconfig
@@ -275,3 +275,14 @@ config DEFAULT_CONSOLE_LOGLEVEL
 
 endmenu
 
+config CONSOLE_BTEXT
+	bool
+	default n
+
+config CONSOLE_SROM
+	bool
+	default n
+
+config CONSOLE_LOGBUF
+	bool
+	default n
Index: svn/src/northbridge/amd/amdfam10/Kconfig
===================================================================
--- svn.orig/src/northbridge/amd/amdfam10/Kconfig
+++ svn/src/northbridge/amd/amdfam10/Kconfig
@@ -21,11 +21,35 @@ config NORTHBRIDGE_AMD_AMDFAM10
 	bool
 	select HAVE_HIGH_TABLES
 	select HYPERTRANSPORT_PLUGIN_SUPPORT
-	select HT3_SUPPORT
 
 config AGP_APERTURE_SIZE
 	hex
 	default 0x4000000
 	depends on NORTHBRIDGE_AMD_AMDFAM10
 
+config HT3_SUPPORT
+	bool
+	default y
+	depends on NORTHBRIDGE_AMD_AMDFAM10
+
+config AMDMCT
+	bool
+	default y
+	depends on NORTHBRIDGE_AMD_AMDFAM10
+
+config MEM_TRAIN_SEQ
+	int
+	default 0
+	depends on NORTHBRIDGE_AMD_AMDFAM10
+
+config HW_MEM_HOLE_SIZEK
+	hex
+	default 0x100000
+	depends on NORTHBRIDGE_AMD_AMDFAM10
+
+config HW_MEM_HOLE_SIZE_AUTO_INC
+	bool
+	default n
+	depends on NORTHBRIDGE_AMD_AMDFAM10
+
 source src/northbridge/amd/amdfam10/root_complex/Kconfig
Index: svn/src/northbridge/amd/amdk8/Kconfig
===================================================================
--- svn.orig/src/northbridge/amd/amdk8/Kconfig
+++ svn/src/northbridge/amd/amdk8/Kconfig
@@ -32,4 +32,19 @@ config K8_HT_FREQ_1G_SUPPORT
 	default n
 	depends on NORTHBRIDGE_AMD_AMDK8
 
+config MEM_TRAIN_SEQ
+	int
+	default 0
+	depends on NORTHBRIDGE_AMD_AMDK8
+
+config HW_MEM_HOLE_SIZEK
+	hex
+	default 0x100000
+	depends on NORTHBRIDGE_AMD_AMDK8
+
+config HW_MEM_HOLE_SIZE_AUTO_INC
+	bool
+	default n
+	depends on NORTHBRIDGE_AMD_AMDK8
+
 source src/northbridge/amd/amdk8/root_complex/Kconfig
Index: svn/src/southbridge/via/vt8237r/vt8237r.h
===================================================================
--- svn.orig/src/southbridge/via/vt8237r/vt8237r.h
+++ svn/src/southbridge/via/vt8237r/vt8237r.h
@@ -65,7 +65,7 @@
 #define I2C_TRANS_CMD			0x40
 #define CLOCK_SLAVE_ADDRESS		0x69
 
-#if DEBUG_SMBUS == 1
+#if defined(DEBUG_SMBUS) && DEBUG_SMBUS == 1
 #define PRINT_DEBUG(x)		print_debug(x)
 #define PRINT_DEBUG_HEX16(x)	print_debug_hex16(x)
 #else
Index: svn/src/mainboard/tyan/s1846/Kconfig
===================================================================
--- svn.orig/src/mainboard/tyan/s1846/Kconfig
+++ svn/src/mainboard/tyan/s1846/Kconfig
@@ -43,9 +43,3 @@ config HAVE_OPTION_TABLE
 	bool
 	default n
 	depends on BOARD_TYAN_S1846
-
-#Override manually, as in Config.lb (FIXME)
-config IRQ_SLOT_COUNT
-	int
-	default 0
-	depends on BOARD_TYAN_S1846
